package com.srs.comprehensive.service.impl;

import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.srs.common.utils.DateUtils;
import com.srs.comprehensive.domain.*;
import com.srs.comprehensive.mapper.QuestionnaireReleaseMapper;
import com.srs.comprehensive.service.IQuestionnaireReleaseService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;


/**
 * 问卷调查Service业务层处理
 *
 * @author srs
 * @date 2024-05-18
 */
@Service
public class QuestionnaireReleaseServiceImpl extends ServiceImpl<QuestionnaireReleaseMapper, QuestionnaireRelease> implements IQuestionnaireReleaseService {

    @Autowired
    private QuestionnaireReleaseMapper releaseMapper;

    /**
     * 查询【请填写功能名称】
     *
     * @param id 【请填写功能名称】主键
     * @return 【请填写功能名称】
     */
    @Override
    public QuestionnaireRelease selectTReleaseById(Long id) {
        return releaseMapper.selectReleaseById(id);
    }

    /**
     * 查询【请填写功能名称】列表
     *
     * @param tRelease 【请填写功能名称】
     * @return 【请填写功能名称】
     */
    @Override
    public List<QuestionnaireRelease> selectReleaseList(QuestionnaireRelease tRelease) {
        return releaseMapper.selectReleaseList(tRelease);
    }

    /**
     * 新增【请填写功能名称】
     *
     * @param tRelease 【请填写功能名称】
     * @return 结果
     */
    @Override
    public int insertTRelease(QuestionnaireRelease tRelease) {
        tRelease.setCreateTime(DateUtils.getNowDate());
        return releaseMapper.insertRelease(tRelease);
    }

    /**
     * 修改【请填写功能名称】
     *
     * @param tRelease 【请填写功能名称】
     * @return 结果
     */
    @Override
    public int updateTRelease(QuestionnaireRelease tRelease) {
        tRelease.setUpdateTime(DateUtils.getNowDate());
        return releaseMapper.updateRelease(tRelease);
    }

    /**
     * 批量删除【请填写功能名称】
     *
     * @param ids 需要删除的【请填写功能名称】主键
     * @return 结果
     */
    @Override
    public int deleteTReleaseByIds(Long[] ids) {
        return releaseMapper.deleteReleaseByIds(ids);
    }

    /**
     * 删除【请填写功能名称】信息
     *
     * @param id 【请填写功能名称】主键
     * @return 结果
     */
    @Override
    public int deleteTReleaseById(Long id) {
        return releaseMapper.deleteReleaseById(id);
    }




}
